@@ -6,7 +6,6 @@ def update_rcParams():
     # This mpl style is from the UCSC BME163 class.
     rcParams.update({
         'font.size'            : 8.0      ,
-        'font.sans-serif'      : 'Arial'    ,
         'xtick.major.size'     : 2        ,
         'xtick.major.width'    : 0.75     ,
         'xtick.labelsize'      : 8.0      ,
@@ -21,8 +20,6 @@ def update_rcParams():
         'ytick.minor.pad'      : 2        ,
         'savefig.dpi'          : 601      ,
         'axes.linewidth'       : 0.75     ,
-        'text.usetex'          : False    ,
         "image.composite_image": False   ,
         "pdf.fonttype"         : 42,
         "ps.fonttype"          : 42  })
-
